@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import importlib
+import warnings
 
 from tornado.options import options
 
@@ -10,8 +11,10 @@ class MysqlSqlAlchemyPool(BaseConnectionPool):
     """
     mysql 数据库链接创建类
     """
+    warnings.warn("此类即将弃用，不推荐使用", DeprecationWarning)
 
     def sync_create_pool(self):
+        warnings.warn("此方法即将弃用，不推荐使用", DeprecationWarning)
         mysql_url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
             self.conn_info.user, self.conn_info.password, self.conn_info.host, self.conn_info.port,
             self.conn_info.db_name)
