@@ -1,5 +1,6 @@
 import importlib
 import random
+import uuid
 
 import tornado.options
 
@@ -21,14 +22,16 @@ async def post(path, data=None,
         if not kwargs.get("headers"):
             kwargs.update({"headers": {
                 "Content-Type": "application/json",
-                "Project-Name": project_name
+                "Project-Name": project_name,
+                "Request-Id": uuid.uuid1().hex
             }})
         else:
             kwargs["headers"].update({"Project-Name": project_name})
     else:
         if not kwargs.get("headers"):
             kwargs.update({"headers": {
-                "Project-Name": project_name
+                "Project-Name": project_name,
+                "Request-Id": uuid.uuid1().hex
             }})
         else:
             kwargs["headers"].update({"Project-Name": project_name})
@@ -75,7 +78,8 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
     project_name = tornado.options.options.project_name.encode("utf-8")
     if not kwargs.get("headers"):
         kwargs.update({"headers": {
-            "Project-Name": project_name
+            "Project-Name": project_name,
+            "Request-Id": uuid.uuid1().hex
         }})
     else:
         kwargs["headers"].update({"Project-Name": project_name})
@@ -109,10 +113,11 @@ def sync_common_request(method, path, params=None, data=None, json=None, base_ur
         base_url = tornado.options.options.data_server
     if not kwargs.get("headers"):
         kwargs.update({"headers": {
-            "Project-Name": project_name
+            "Project-Name": project_name,
+            "Request-Id": uuid.uuid1().hex
         }})
     else:
-        kwargs["headers"].update({"Project-Name": project_name})
+        kwargs["headers"].update({"Project-Name": project_name, "Request-Id": uuid.uuid1().hex})
     if not connect_config:
         connect_config = {
             "pool_connections": 10,
