@@ -61,6 +61,8 @@ def Handler(url: str, desc=""):
             handler = item[1]
             # 全路径 Handler+Mapping 组合
             full_url = route_prefix + url + item[2]
+            if tornado.options.options.url_log_enable:
+                logging.info(f"url={full_url}")
             # 判断是否存在重复注册情况，重复情况直接抛出异常
             # if [router for router in RouterMapping.instance() if full_url in router]:
             #     raise BusinessException(StatusCode.RESOURCE_EXIST(f'路由"{full_url}"'))
