@@ -17,6 +17,7 @@ from tornado.options import options, define
 from lesscode.db.init_connection_pool import InitConnectionPool
 from lesscode.extend_handlers.not_found_handler import NotFoundHandler
 from lesscode.sentry.sentry_monitor import sentry_monitor
+from lesscode.task.job_info import JobInfo
 from lesscode.web.router_mapping import RouterMapping
 
 define("application_name", default=f"{os.path.split(os.path.abspath(os.path.dirname(sys.argv[0])))[-1]}", type=str,
@@ -58,6 +59,7 @@ define("sentry_config", default={"enable": False}, type=dict, help="sentry配置
 define("login_verification_func", default=None, type=object, help="登录验证函数")
 define("cors", default=None, type=dict, help="跨域策略")
 define("url_log_enable", default=False, type=bool, help="项目url打印")
+define("cronjob_config", default={}, type=dict, help="定时任务配置")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -219,6 +221,18 @@ class WebServer:
                     task_kwargs = task.get("kwargs", {})
                     if task_func:
                         options.scheduler.add_job(func=task_func, **task_kwargs)
+        if options.cronjob_config:
+            cronjob_config = options.cronjob_config
+            if cronjob_config.get("enable"):
+                job_list = cronjob_config.get("job_list")
+                if job_list:
+                    for job in job_list:
+                        if isinstance(job, JobInfo):
+                            options.scheduler.add_job(func=job.func, trigger='cron', year=job.year, month=job.month,
+                                                      day=job.day, week=job.week, day_of_week=job.day_of_week,
+                                                      hour=job.hour, minute=job.minute, second=job.second,
+                                                      start_date=job.start_date, end_date=job.end_date,
+                                                      args=job.func_args, kwargs=job.kwargs, *job.args, **job.kwargs)
 
     def service_register(self):
         try:
